==> xpcs_viewer-0.255-py3-none-any.whl: xpcs_viewer/fileIO/aps_8idi.py <==
key = {
  "saxs_1d": "/exchange/partition-mean-total",
  "Iqp": "/exchange/partition-mean-partial",
  "ql_sta": "/xpcs/sqlist",
  "ql_dyn": "/xpcs/dqlist",
  "dqmap": "/xpcs/dqmap",
  "sqmap": "/xpcs/sqmap",
  "mask": "/xpcs/mask",
  "type": "/xpcs/analysis_type",
  "t0": "/measurement/instrument/detector/exposure_period",
  "t1": "/measurement/instrument/detector/exposure_time",
  "tau": "/exchange/tau",
  "g2": "/exchange/norm-0-g2",
  "g2_err": "/exchange/norm-0-stderr",
  "saxs_2d": "/exchange/pixelSum",
  "Int_t": "/exchange/frameSum",
  "avg_frames": "/xpcs/avg_frames",
  "stride_frames": "/xpcs/stride_frames",
  "ccd_x0": "/measurement/instrument/acquisition/beam_center_x",
  "ccd_y0": "/measurement/instrument/acquisition/beam_center_y",
  "det_dist": "/measurement/instrument/detector/distance",
  "pix_dim_x": "/measurement/instrument/detector/x_pixel_size",
  "pix_dim_y": "/measurement/instrument/detector/y_pixel_size",
  "X_energy": "/measurement/instrument/source_begin/energy",
  "xdim": "/measurement/instrument/detector/x_dimension",
  "ydim": "/measurement/instrument/detector/y_dimension",
  "c2_half": "/exchange/C2T_all",
  "g2_full": "/exchange/g2full",
  "g2_partials": "/exchange/g2partials",
  "G2": "/exchange/G2",
  "IP": "/exchange/IP",
  "IF": "/exchange/IF",
  "snophi": "/xpcs/snophi",
  "snoq": "/xpcs/snoq",
  "sphilist": "/xpcs/sphilist",
  "dnophi": "/xpcs/dnophi",
  "dnoq": "/xpcs/dnoq",
  "dphilist": "/xpcs/dphilist",
  "sphispan": "/xpcs/sphispan",
  "sqspan": "/xpcs/sqspan",
}

==> xpcs_viewer-0.258-py3-none-any.whl: xpcs_viewer/fileIO/aps_8idi.py <==
key = {
  "saxs_1d": "/exchange/partition-mean-total",
  "Iqp": "/exchange/partition-mean-partial",
  "ql_sta": "/xpcs/sqlist",
  "ql_dyn": "/xpcs/dqlist",
  "dqmap": "/xpcs/dqmap",
  "sqmap": "/xpcs/sqmap",
  "mask": "/xpcs/mask",
  "type": "/xpcs/analysis_type",
  "t0": "/measurement/instrument/detector/exposure_period",
  "t1": "/measurement/instrument/detector/exposure_time",
  "tau": "/exchange/tau",
  "g2": "/exchange/norm-0-g2",
  "g2_err": "/exchange/norm-0-stderr",
  "saxs_2d": "/exchange/pixelSum",
  "Int_t": "/exchange/frameSum",
  "avg_frames": "/xpcs/avg_frames",
  "stride_frames": "/xpcs/stride_frames",
  "bcx": "/measurement/instrument/acquisition/beam_center_x",
  "bcy": "/measurement/instrument/acquisition/beam_center_y",
  "ccdx": "/measurement/instrument/acquisition/stage_x",
  "ccdx0": "/measurement/instrument/acquisition/stage_zero_x",
  "ccdy": "/measurement/instrument/acquisition/stage_z",
  "ccdy0": "/measurement/instrument/acquisition/stage_zero_z",
  "det_dist": "/measurement/instrument/detector/distance",
  "pix_dim_x": "/measurement/instrument/detector/x_pixel_size",
  "pix_dim_y": "/measurement/instrument/detector/y_pixel_size",
  "X_energy": "/measurement/instrument/source_begin/energy",
  "xdim": "/measurement/instrument/detector/x_dimension",
  "ydim": "/measurement/instrument/detector/y_dimension",
  "c2_half": "/exchange/C2T_all",
  "g2_full": "/exchange/g2full",
  "g2_partials": "/exchange/g2partials",
  "G2": "/exchange/G2",
  "IP": "/exchange/IP",
  "IF": "/exchange/IF",
  "snophi": "/xpcs/snophi",
  "snoq": "/xpcs/snoq",
  "sphilist": "/xpcs/sphilist",
  "dnophi": "/xpcs/dnophi",
  "dnoq": "/xpcs/dnoq",
  "dphilist": "/xpcs/dphilist",
  "sphispan": "/xpcs/sphispan",
  "sqspan": "/xpcs/sqspan",
  "abs_cross_section_scale": "/measurement/sample/absolute_cross_section_scale",
}
